@@ -88,8 +88,11 @@ class DKConnection():
     def getOrder(self, kitchen, order_id):
         return self.OrderInfo(kitchen, order_id)
 
+    def getOrderRun(self, kitchen, order_id):
+        return self.OrderRunInfo(kitchen, order_id)
+
     def TestsFromOrderRun(self, kitchen, order_run_id):
-        return self.getOrderRun(kitchen, order_run_id).getTests()
+        return self.getOrderRun(kitchen, order_run_id).testsFromOrderRun()
 
     def OrderStatus(self, kitchen, order_run):
         return self.getOrder(kitchen, order_run_id).getOrderStatus()
